//----------------------------------------------------------------------------------------------------
// Debug module
//
// Geoff Audy, October 11th 2000
// Geoff Audy, October 25th 2000 (Changed the function named 'DEBUG_PrintDebugWindow' to 'DEBUG_Print'
// Geoff Audy, October 28th 2000 (Added functions 'DEBUG_SetMode')

// Copyright (C)2002 Sony Computer Entertainment America Inc.
//
// This file is subject to the terms and conditions of the GNU
// General Public Licence Version 2.  See the file "COPYING"
// in the main directory of this archive for more details.
//----------------------------------------------------------------------------------------------------

#include "debug.h"
#include <time.h>

#define  DEBUG_OUTPUT_FILENAME  "DEBUG.LOG"

//-------------------------------------
static unsigned int  DEBUG_Mode = DEBUG_MODE_OFF;  // By default, no debug info

//-------------------------------------
//
//-------------------------------------
void DEBUG_Print (char *formatstr, ...)
{
   va_list      params;
   static char  string[1024];

   // Don't output anything if debug is off
   if (DEBUG_Mode & DEBUG_MODE_OFF)
      return;

   va_start (params, formatstr);

   // Create the output string from the params
   vsprintf (string, formatstr, params);

   if (DEBUG_Mode & DEBUG_MODE_PRINT)
   {
      // Effectively output the string
      printf (string);
   }
   else
   {
      // Output the string to the log file
      FILE  *fp;

      if ((fp = fopen (DEBUG_OUTPUT_FILENAME, "at")) == NULL)
         return;
      fprintf (fp, "%s", string);
      fclose (fp);
   }

   va_end (params);
}

//-------------------------------------
//
//-------------------------------------
unsigned int DEBUG_SetMode (unsigned int mode)
{
   int  tempval;

   // Make sure there's no conflicts in the bitfield
   tempval = mode & (DEBUG_MODE_ON | DEBUG_MODE_OFF);
   if ((tempval != DEBUG_MODE_ON) && (tempval != DEBUG_MODE_OFF))
      return (DEBUG_RET_INVALIDPARAMETER);

   if (tempval == DEBUG_MODE_OFF)
      DEBUG_Mode = DEBUG_MODE_OFF;
   else
   {
      // Make sure there's no conflicts in the bitfield
      tempval = mode & (DEBUG_MODE_FILE | DEBUG_MODE_PRINT);
      if ((tempval != DEBUG_MODE_FILE) && (tempval != DEBUG_MODE_PRINT))
         return (DEBUG_RET_INVALIDPARAMETER);

      // Set the module's debug flags
      DEBUG_Mode = DEBUG_MODE_ON | tempval;
   }

   // If we're asked to output to a file, create the file if necessary, and then output some time stamp into it
   if ((DEBUG_Mode & DEBUG_MODE_ON) && (DEBUG_Mode & DEBUG_MODE_FILE))
   {
      FILE  *fp;

      if ((fp = fopen (DEBUG_OUTPUT_FILENAME, "rb")) == NULL)
      {
         // The file doesn't exist.  Create it
         if ((fp = fopen (DEBUG_OUTPUT_FILENAME, "wb")) == NULL)
         {
            // We can't create the file.  Set debug mode to OFF, and return an error message
            DEBUG_Mode = DEBUG_MODE_OFF;

            return (DEBUG_RET_ERROR);
         }
         else
            fclose (fp);
      }
      else
         fclose (fp);

      // Time stamp output
      {
         char  timestr[16] = "unknown";
         char  datestr[16] = "unknown";

//         _strtime (timestr);
//         _strdate (datestr);
         DEBUG_Print ("\n\n\n\n\n");
         DEBUG_Print ("---------------------------- Debug log file enabled at %s on %s ----------------------------\n",
                      timestr, datestr);
      }
   }

   // Everything was fine
   return (DEBUG_RET_OK);
}

